% Loading from data files (m895_ro, morn_ro) and visualizing density maps
% for pyrolite (m895_ro) and MORB (morn_ro) 
% and density difference between pyrolite and MORB

% Clearing all variables and arrays
clear all;
% Clearing figures
clf;

% Loading data from files
% m895_ro
% Opening data file
fdata=fopen('m895_ro','rt');
% Skipping rock title
a=fscanf(fdata,'%s',1);
% Loading resolutions for T and P
tnum=fscanf(fdata,'%f',1);
pnum=fscanf(fdata,'%f',1);
% Loading starting values T(K) and P(bar)
tmin=fscanf(fdata,'%f',1);
pmin=fscanf(fdata,'%f',1);
% Loading steps for T(K) and P(bar)
tstp=fscanf(fdata,'%f',1);
pstp=fscanf(fdata,'%f',1);
% Skipping titles for P and T
b=fscanf(fdata,'%s',2);
% Creating density array
rhomantle=zeros(pnum,tnum);
% Loading density data
for i=1:1:pnum
    for j=1:1:tnum
        rhomantle(i,j)=fscanf(fdata,'%f',1);
    end
end
% Closing data file
fclose(fdata);

% morn_ro
% Opening data file
fdata=fopen('morn_ro','rt');
% Skipping rock title
a=fscanf(fdata,'%s',1);
% Loading resolutions for T and P
tnum=fscanf(fdata,'%f',1);
pnum=fscanf(fdata,'%f',1);
% Loading starting values T(K) and P(bar)
tmin=fscanf(fdata,'%f',1);
pmin=fscanf(fdata,'%f',1);
% Loading steps for T(K) and P(bar)
tstp=fscanf(fdata,'%f',1);
pstp=fscanf(fdata,'%f',1);
% Skipping titles for P and T
b=fscanf(fdata,'%s',2);
% Creating density array
rhocrust=zeros(pnum,tnum);
% Loading density data
for i=1:1:pnum
    for j=1:1:tnum
        rhocrust(i,j)=fscanf(fdata,'%f',1);
    end
end
% Closing data file
fclose(fdata);

% Defining new figure
figure(1)

% 2D colormap
% Creating a vector of arguments for two axes
for i=1:1:pnum
    p(i)=pmin*1e-4+(i-1)*pstp*1e-4; % Pressure GPa (1 bar = 10^5 Pa = 10^(-4) GPa
end
for j=1:1:tnum
    t(j)=tmin-273+(j-1)*tstp; % T C
end

% Plotting mantle density
subplot(2,2,1);     % defining 2nd plotting area in the 3x1 figure
pcolor(t,p,rhomantle);      % making colormap
box on;             % making box around the plot
title('Pirolite density, kg/m^3');   % title of the plot
xlabel('T,C');        % title of horizontal axis
ylabel('P,GPa');        % title of vertical axis
shading interp;     % making smooth transitions between colors
colorbar;           % showing colorbar for the map

% Plotting crust density
subplot(2,2,2);     % defining 2nd plotting area in the 3x1 figure
pcolor(t,p,rhocrust);      % making colormap
box on;             % making box around the plot
title('MORB density, kg/m^3');   % title of the plot
xlabel('T,C');        % title of horizontal axis
ylabel('P,GPa');        % title of vertical axis
shading interp;     % making smooth transitions between colors
colorbar;           % showing colorbar for the map

% Plotting mantle-crust density difference
subplot(2,2,3);     % defining 2nd plotting area in the 3x1 figure
pcolor(t,p,rhomantle-rhocrust);      % making colormap
box on;             % making box around the plot
title('Pirolite-MORB density difference, kg/m^3');   % title of the plot
xlabel('T,C');        % title of horizontal axis
ylabel('P,GPa');        % title of vertical axis
shading interp;     % making smooth transitions between colors
colorbar;           % showing colorbar for the map





